==> knative-model-4.12.0-sources.jar: io/fabric8/knative/sources/v1beta1/ApiServerSourceBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ApiServerSourceBuilder extends ApiServerSourceFluentImpl<ApiServerSourceBuilder> implements VisitableBuilder<ApiServerSource,ApiServerSourceBuilder> {

    ApiServerSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ApiServerSourceBuilder() { 
        this(true);
    }


    public ApiServerSourceBuilder(Boolean validationEnabled) { 
        this(new ApiServerSource(), validationEnabled);
    }


    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent) { 
        this(fluent, true);
    }


    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ApiServerSource(), validationEnabled);
    }


    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent,ApiServerSource instance) { 
        this(fluent, instance, true);
    }


    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent,ApiServerSource instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public ApiServerSourceBuilder(ApiServerSource instance) { 
        this(instance,true);
    }


    public ApiServerSourceBuilder(ApiServerSource instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public ApiServerSource build() {
        ApiServerSource buildable = new ApiServerSource(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ApiServerSourceBuilder that = (ApiServerSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: io/fabric8/knative/sources/v1beta1/ApiServerSourceBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ApiServerSourceBuilder extends ApiServerSourceFluentImpl<ApiServerSourceBuilder> implements VisitableBuilder<ApiServerSource,ApiServerSourceBuilder> {

    ApiServerSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ApiServerSourceBuilder() {
        this(true);
    }

    public ApiServerSourceBuilder(Boolean validationEnabled) {
        this(new ApiServerSource(), validationEnabled);
    }

    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent) {
        this(fluent, true);
    }

    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ApiServerSource(), validationEnabled);
    }

    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent,ApiServerSource instance) {
        this(fluent, instance, true);
    }

    public ApiServerSourceBuilder(ApiServerSourceFluent<?> fluent,ApiServerSource instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ApiServerSourceBuilder(ApiServerSource instance) {
        this(instance,true);
    }

    public ApiServerSourceBuilder(ApiServerSource instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableApiServerSource build() {
        EditableApiServerSource buildable = new EditableApiServerSource(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ApiServerSourceBuilder that = (ApiServerSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
